package com.contentsquare.flutter.infrastructure.bridges

import com.contentsquare.android.error.analysis.ErrorAnalysis
import com.contentsquare.android.error.analysis.NetworkMetric

/**
 * Bridge to error analysis module
 */
internal interface ErrorAnalysisBridge {

    /**
     * Set url masking patterns to ErrorAnalysis API.
     *
     * @param patterns the patterns that must be set.
     */
    fun setUrlMaskingPatterns(patterns: List<String>)

    /** Send [NetworkMetric] to [ErrorAnalysis] module.
     *
     * @param networkMetric the [NetworkMetric] to send.
     */
    fun sendApiError(networkMetric: NetworkMetric)

    companion object Singleton {
        private var instance: ErrorAnalysisBridge? = null

        /**
         * Get the instance of the default implementation of [ContentsquareSDKBridge].
         */
        fun getInstance(): ErrorAnalysisBridge {
            if (instance == null) {
                instance = ErrorAnalysisBridgeImpl()
            }

            return instance as ErrorAnalysisBridge
        }
    }
}

/**
 * Implementation of [ErrorAnalysisBridge] that uses [ErrorAnalysis].
 */
internal class ErrorAnalysisBridgeImpl : ErrorAnalysisBridge {
    override fun setUrlMaskingPatterns(patterns: List<String>) {
        ErrorAnalysis.setUrlMaskingPatterns(patterns)
    }

    override fun sendApiError(networkMetric: NetworkMetric) {
        networkMetric.start()
        networkMetric.stop()
    }

}