package com.contentsquare.flutter.infrastructure.core.method_call_executor

import com.contentsquare.flutter.infrastructure.core.method_call_executor.agents.MethodCallAgent
import com.contentsquare.flutter.infrastructure.core.method_call_executor.data.ExecutionData
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.NotAvailableExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.SuccessExecutionResponse
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel.Result

/**
 * Used to execute the difference method from [MethodCall]
 */
internal class MethodCallExecutor {
    /**
     * Proceeds with the execution by the agent and pass the response in the result.
     *
     * @param agent the [MethodCallAgent] used to execute the data
     * @param data the [ExecutionData] that will be executed by the agent
     * @param result the [Result] used to pass the response of the execution by the agent
     */
    fun execute(agent: MethodCallAgent, data: ExecutionData, result: Result) {
        when (val response = agent.safeExecute(data)) {
            is SuccessExecutionResponse -> {
                result.success(response.result)
            }

            is FailedExecutionResponse -> {
                result.error(response.reason.code, response.message, response.cause)
            }

            is NotAvailableExecutionResponse -> {
                result.notImplemented()
            }
        }
    }
}



