package com.contentsquare.flutter.infrastructure.core.method_call_executor.agents

import com.contentsquare.flutter.infrastructure.core.method_call_executor.data.ExecutionData
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.ExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponseReason
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.SuccessExecutionResponse
import com.contentsquare.flutter.infrastructure.proxies.CollectCustomTelemetryProxy


/**
 * Agent used to execute custom telemetry collection.
 */
internal class CollectCustomTelemetryAgent(private val proxy: CollectCustomTelemetryProxy = CollectCustomTelemetryProxy.default()): MethodCallAgent(nativeExceptionMessage) {
    companion object {
        /** Message to use in case of error during native call. */
        const val nativeExceptionMessage = "Failed to collect data"

        /** Message in case of "value" parameter missing. */
        const val missingValueMessage = "Missing string for the value parameter"

        /** Message in case of "name" parameter missing. */
        const val missingNameMessage = "Missing string for the name parameter"
    }

    override fun execute(data: ExecutionData): ExecutionResponse {
        val value = data.call.argument<String>("value")
            ?: return FailedExecutionResponse(FailedExecutionResponseReason.MISSING_ARGUMENT, missingValueMessage, null)
        val name = data.call.argument<String>("name")
            ?: return FailedExecutionResponse(FailedExecutionResponseReason.MISSING_ARGUMENT, missingNameMessage, null)

        proxy.collect(name, value)

        return SuccessExecutionResponse.empty()
    }
}