package com.contentsquare.flutter.infrastructure.core.method_call_executor.agents

import com.contentsquare.flutter.infrastructure.core.method_call_executor.data.ExecutionData
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.ExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponseReason
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.SuccessExecutionResponse
import com.contentsquare.flutter.infrastructure.proxies.CollectXPFVersionProxy


/**
 * Agent used to execute XPF version telemetry collection.
 */
internal class CollectXPFVersionAgent(private val proxy: CollectXPFVersionProxy = CollectXPFVersionProxy.default()): MethodCallAgent(nativeExceptionMessage) {
    companion object {
        /** Message to use in case of error during native call. */
        const val nativeExceptionMessage = "Failed to collect version"

        /** Message in case of "version" parameter missing. */
        const val missingVersionMessage = "Missing string for the version parameter"
    }

    override fun execute(data: ExecutionData): ExecutionResponse {
        val version = data.call.argument<String>("version")
            ?: return FailedExecutionResponse(FailedExecutionResponseReason.MISSING_ARGUMENT, missingVersionMessage, null)

        proxy.collect(version)

        return SuccessExecutionResponse.empty()
    }
}
