package com.contentsquare.flutter.infrastructure.core.method_call_executor.agents

import com.contentsquare.flutter.infrastructure.core.method_call_executor.data.ExecutionData
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.ExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponseReason
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.SuccessExecutionResponse
import com.contentsquare.flutter.infrastructure.proxies.OptInProxy


/**
 * Agent used to execute OptIn.
 */
internal class OptInAgent(private val proxy: OptInProxy = OptInProxy.default()): MethodCallAgent(OptInAgent.nativeExceptionMessage) {
    companion object {
        /** Message to use in case of error during native call. */
        val nativeExceptionMessage = "Failed to ${AgentMethod.OPT_IN.method}"

        /** Message in case of "context" parameter missing. */
        const val missingContextMessage = "Cannot call optIn without context, please wait for FlutterEngine to start. This can happen if you call the optIn method from the global scope or from outside a build method."
    }

    override fun execute(data: ExecutionData): ExecutionResponse {
        if (data.context == null) {
            return FailedExecutionResponse(FailedExecutionResponseReason.NO_CONTEXT, missingContextMessage, null)
        }

        proxy.optIn(data.context)

        return SuccessExecutionResponse.empty()
    }
}