package com.contentsquare.flutter.infrastructure.core.method_call_executor.agents

import com.contentsquare.flutter.infrastructure.core.method_call_executor.data.ExecutionData
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.ExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponseReason
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.SuccessExecutionResponse
import com.contentsquare.flutter.infrastructure.proxies.OptOutProxy


/**
 * Agent used to execute OptOut.
 */
internal class OptOutAgent(private val proxy: OptOutProxy = OptOutProxy.default()): MethodCallAgent(nativeExceptionMessage) {
    companion object {
        /** Message to use in case of error during native call. */
        val nativeExceptionMessage = "Failed to ${AgentMethod.OPT_OUT.method}"

        /** Message in case of "context" parameter missing. */
        const val missingContextMessage = "Cannot call optOut without context, please wait for FlutterEngine to start. This can happen if you call the optOut method from the global scope or from outside a build method."
    }

    override fun execute(data: ExecutionData): ExecutionResponse {
        if (data.context == null) {
            return FailedExecutionResponse(FailedExecutionResponseReason.NO_CONTEXT, missingContextMessage, null)
        }

        proxy.optOut(data.context)

        return SuccessExecutionResponse.empty()
    }
}