package com.contentsquare.flutter.infrastructure.core.method_call_executor.agents

import com.contentsquare.flutter.infrastructure.core.method_call_executor.data.ExecutionData
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.ExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponseReason
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.SuccessExecutionResponse
import com.contentsquare.flutter.infrastructure.proxies.ContentsquareLongDynamicVar
import com.contentsquare.flutter.infrastructure.proxies.ContentsquareStringDynamicVar
import com.contentsquare.flutter.infrastructure.proxies.SendDynamicVarProxy


/**
 * Agent used to execute resume tracking.
 */
internal class SendDynamicVarAgent(private val proxy: SendDynamicVarProxy = SendDynamicVarProxy.default()): MethodCallAgent(nativeExceptionMessage) {
    companion object {
        /** Message to use in case of error during native call. */
        const val nativeExceptionMessage = "Failed to send dynamic var"

        /** Message in case of "key" parameter missing. */
        const val missingKeyMessage = "Missing string for the key parameter"

        /** Message in case of "intValue" and "stringValue" parameter missing. */
        const val missingIntValueAndStringValueMessage = "Either stringValue or intValue parameter should be provided"
    }

    override fun execute(data: ExecutionData): ExecutionResponse {
        val key = data.call.argument<String>("key")
            ?: return FailedExecutionResponse(FailedExecutionResponseReason.MISSING_ARGUMENT, missingKeyMessage, null)

        val stringValue = data.call.argument<String>("stringValue")
        val intValue = data.call.argument<Int>("intValue")

        if (stringValue == null && intValue == null) {
            return FailedExecutionResponse(FailedExecutionResponseReason.MISSING_ARGUMENT, missingIntValueAndStringValueMessage, null)
        }

        if (stringValue != null) {
            proxy.send(ContentsquareStringDynamicVar(stringValue, key))
        } else if (intValue != null) {
            proxy.send(ContentsquareLongDynamicVar(intValue.toLong(), key))
        }

        return SuccessExecutionResponse.empty()
    }
}