package com.contentsquare.flutter.infrastructure.core.method_call_executor.agents

import com.contentsquare.flutter.infrastructure.core.method_call_executor.data.ExecutionData
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.ExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponseReason
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.SuccessExecutionResponse
import com.contentsquare.flutter.infrastructure.proxies.CustomVariable
import com.contentsquare.flutter.infrastructure.proxies.SendScreenNameProxy


/**
 * Agent used to execute send screen name.
 */
internal class SendScreenNameAgent(private val proxy: SendScreenNameProxy = SendScreenNameProxy.default()): MethodCallAgent(nativeExceptionMessage) {
    companion object {
        /** Message to use in case of error during native call. */
        const val nativeExceptionMessage = "Failed to send"

        /** Message in case of "screenName" parameter missing. */
        const val missingScreenNameMessage = "Missing string for the screenName parameter"
    }

    override fun execute(data: ExecutionData): ExecutionResponse {
        val screenName = data.call.argument<String>("screenName")
            ?: return FailedExecutionResponse(FailedExecutionResponseReason.MISSING_ARGUMENT, missingScreenNameMessage, null)

        val cVarsArg = data.call.argument<ArrayList<HashMap<String, Any>>>("customVars")?: ArrayList();
        val customVariables = cVarsArg.map {
            val index = it["index"] as Int
            val name = it["name"] as String
            val value = it["value"] as String

            CustomVariable(
                    index,
                    name,
                    value,
            )
        }.toTypedArray()

        proxy.send(screenName, customVariables)

        return SuccessExecutionResponse.empty()
    }
}