package com.contentsquare.flutter.infrastructure.core.method_call_executor.agents

import com.contentsquare.flutter.infrastructure.core.method_call_executor.data.ExecutionData
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.ExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponseReason
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.SuccessExecutionResponse
import com.contentsquare.flutter.infrastructure.proxies.SendSessionReplayProtoDataListProxy

internal class SendSessionReplayProtoDataListAgent(private val proxy: SendSessionReplayProtoDataListProxy = SendSessionReplayProtoDataListProxy.default()): MethodCallAgent(nativeExceptionMessage) {

    companion object {
        /** Message to use in case of error during native call. */
        const val nativeExceptionMessage = "Failed to send session replay data"

        /** Message in case of "data" parameter missing. */
        const val missingBodyMessage = "Missing ByteArray for the data parameter"

    }

    override fun execute(data: ExecutionData): ExecutionResponse {
        val protoData = data.call.argument<ByteArray>("data")
                ?: return FailedExecutionResponse(FailedExecutionResponseReason.MISSING_ARGUMENT, missingBodyMessage, null)

        proxy.send(listOf(protoData))

        return SuccessExecutionResponse.empty()
    }

}