package com.contentsquare.flutter.infrastructure.core.method_call_executor.agents

import com.contentsquare.flutter.infrastructure.core.method_call_executor.data.ExecutionData
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.ExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponseReason
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.SuccessExecutionResponse
import com.contentsquare.flutter.infrastructure.proxies.SendTouchEventProxy


/**
 * Agent used to execute send touch event.
 */
internal class SendTouchEventAgent(private val proxy: SendTouchEventProxy = SendTouchEventProxy.default()): MethodCallAgent(nativeExceptionMessage) {
    companion object {
        /** Message to use in case of error during native call. */
        const val nativeExceptionMessage = "Failed to send touch event"

        /** Message in case of "body" parameter missing. */
        const val missingBodyMessage = "Missing string for the body parameter"
    }

    override fun execute(data: ExecutionData): ExecutionResponse {
        val body = data.call.argument<String>("body")
            ?: return FailedExecutionResponse(FailedExecutionResponseReason.MISSING_ARGUMENT, missingBodyMessage, null)

        proxy.send(body)

        return SuccessExecutionResponse.empty()
    }
}