package com.contentsquare.flutter.infrastructure.core.method_call_executor.agents

import com.contentsquare.flutter.infrastructure.core.method_call_executor.data.ExecutionData
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.ExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponseReason
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.SuccessExecutionResponse
import com.contentsquare.flutter.infrastructure.proxies.ContentsquareTransactionWithID
import com.contentsquare.flutter.infrastructure.proxies.ContentsquareTransactionWithoutID
import com.contentsquare.flutter.infrastructure.proxies.SendTransactionProxy


/**
 * Agent used to execute send transaction.
 */
internal class SendTransactionAgent(private val proxy: SendTransactionProxy = SendTransactionProxy.default()): MethodCallAgent(nativeExceptionMessage) {
    companion object {
        /** Message to use in case of error during native call. */
        const val nativeExceptionMessage = "Failed to send transaction"

        /** Message in case of "price" parameter missing. */
        const val missingPriceMessage = "Missing double for the price parameter"

        /** Message in case of "price" parameter missing. */
        const val missingCurrencyMessage = "Missing string for the currency parameter"
    }

    override fun execute(data: ExecutionData): ExecutionResponse {
        val price = data.call.argument<Double>("price")
            ?: return FailedExecutionResponse(FailedExecutionResponseReason.MISSING_ARGUMENT, missingPriceMessage, null)
        val currency = data.call.argument<String>("currency")
            ?: return FailedExecutionResponse(FailedExecutionResponseReason.MISSING_ARGUMENT, missingCurrencyMessage, null)
        val transactionId = data.call.argument<String>("transactionId")

        if (transactionId != null) {
            proxy.sendTransaction(ContentsquareTransactionWithID(transactionId, price.toFloat(), currency))
        } else {
            proxy.sendTransaction(ContentsquareTransactionWithoutID(price.toFloat(), currency))
        }
        return SuccessExecutionResponse.empty()
    }
}