package com.contentsquare.flutter.infrastructure.core.method_call_executor.agents

import com.contentsquare.flutter.infrastructure.core.method_call_executor.data.ExecutionData
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.ExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponseReason
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.SuccessExecutionResponse
import com.contentsquare.flutter.infrastructure.proxies.SendUserIdentifierProxy

/**
 * Agent used to execute send user identifier
 */
internal class SendUserIdentifierAgent(private val proxy: SendUserIdentifierProxy = SendUserIdentifierProxy.default()) : MethodCallAgent(nativeExceptionMessage) {
    companion object {
        /** Message to use in case of error during native call. */
        const val nativeExceptionMessage = "Failed to send user identifier"

        /** Message in case of "userIdentifier" parameter missing. */
        const val missingUserIdentifierMessage = "Missing string for the userIdentifier parameter"
    }

    override fun execute(data: ExecutionData): ExecutionResponse {
        val userIdentifier = data.call.argument<String>("userIdentifier")
                ?: return FailedExecutionResponse(FailedExecutionResponseReason.MISSING_ARGUMENT, missingUserIdentifierMessage, null)

        proxy.send(userIdentifier)

        return SuccessExecutionResponse.empty()
    }
}