package com.contentsquare.flutter.infrastructure.core.method_call_executor.agents

import com.contentsquare.flutter.infrastructure.core.method_call_executor.data.ExecutionData
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.ExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponse
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.FailedExecutionResponseReason
import com.contentsquare.flutter.infrastructure.core.method_call_executor.responses.SuccessExecutionResponse
import com.contentsquare.flutter.infrastructure.proxies.SetURLMaskingPatternsProxy


/**
 * Agent used to execute set URL Masking patterns.
 */
internal class SetURLMaskingPatternsAgent(private val proxy: SetURLMaskingPatternsProxy = SetURLMaskingPatternsProxy.default()): MethodCallAgent(nativeExceptionMessage) {
    companion object {
        /** Message to use in case of error during native call. */
        const val nativeExceptionMessage = "Failed to set URL masking patterns"

        /** Message in case of "patterns" parameter missing. */
        const val missingPatternsMessage = "Missing list of strings for the patterns parameter"
    }

    override fun execute(data: ExecutionData): ExecutionResponse {
        val patterns = data.call.argument<List<String>>("patterns")
            ?: return FailedExecutionResponse(FailedExecutionResponseReason.MISSING_ARGUMENT, missingPatternsMessage, null)

        proxy.setURLMaskingPatterns(patterns)

        return SuccessExecutionResponse.empty()
    }
}