package com.contentsquare.flutter.infrastructure.core.states

/**
 * A class that holds the state of the Native SDK.
 * The state is composed of:
 * * sessionReplayEnabled: true if session replay is enabled, false otherwise.
 * * containerViewId: not null if the session replay is enabled and the container view id is set, null otherwise.
 * * apiErrorsEnabled: true if api errors are enabled, false otherwise.
 * * crashReporterEnabled: true if crash reporter is enabled, false otherwise.
 * * featureFlags: list of project feature flags.
 */
object ContentsquarePluginState {
    private var csInAppEnabled: Boolean = false
    private var sessionReplayEnabled: Boolean = false
    private var containerViewId: Int? = null
    private var pixelRatio = 1.0
    private var apiErrorsEnabled: Boolean = false
    private var crashReporterEnabled: Boolean = false
    private var featureFlags: List<Map<String, Any>> = emptyList()

    fun setSessionReplayState(enable : StateObject<Boolean>) {
        sessionReplayEnabled = enable.value
    }

    fun setContainerViewIdState(id : StateObject<Int?>) {
        containerViewId = id.value
    }

    fun setPixelRatioState(ratio : StateObject<Double>) {
        pixelRatio = ratio.value
    }

    fun setApiErrorsState(enable : StateObject<Boolean>) {
        apiErrorsEnabled = enable.value
    }

    fun setCrashReporterState(enable : StateObject<Boolean>) {
        crashReporterEnabled = enable.value
    }

    fun setFeatureFlagsState(featureFlagsState: StateObject<List<Map<String, Any>>>) {
        featureFlags = featureFlagsState.value
    }

    fun setCsInAppState(enable : StateObject<Boolean>) {
        csInAppEnabled = enable.value
    }

    fun getSessionReplayState() : StateObject<Boolean> {
        return StateObject(sessionReplayEnabled)
    }

    fun getContainerViewIdState() : StateObject<Int?> {
        return StateObject(containerViewId)
    }

    fun getPixelRatioState() : StateObject<Double> {
        return StateObject(pixelRatio)
    }

    fun getApiErrorsState() : StateObject<Boolean> {
        return StateObject(apiErrorsEnabled)
    }

    fun getCrashReporterState() : StateObject<Boolean> {
        return StateObject(crashReporterEnabled)
    }

    fun getFeatureFlagsState() : StateObject<List<Map<String, Any>>> {
        return StateObject(featureFlags)
    }

    fun getCsInAppState() : StateObject<Boolean> {
        return StateObject(csInAppEnabled)
    }
}

/**
 * A class that represents the type of a state.
 */
class StateObject<T>(val value: T)