package com.contentsquare.flutter.infrastructure.proxies

import com.contentsquare.flutter.infrastructure.bridges.TelemetryInterfaceBridge

/**
 * Allows to collect custom telemetry the flutter to Contentsquare API.
 */
internal interface CollectCustomTelemetryProxy {
    /**
     * Collect custom telemetry.
     *
     * @param name the name of the telemetry
     * @param value the value of the telemetry
     */
    fun collect(name: String, value: String)

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [CollectCustomTelemetryProxy].
         */
        fun default(telemetryInterfaceBridge: TelemetryInterfaceBridge = TelemetryInterfaceBridge.default()): CollectCustomTelemetryProxy {
            return CollectCustomTelemetryProxyImpl(telemetryInterfaceBridge)
        }
    }
}

/**
 * An implementation of [CollectCustomTelemetryProxy].
 *
 * @see CollectCustomTelemetryProxy
 */
internal class CollectCustomTelemetryProxyImpl(private val telemetryInterfaceBridge: TelemetryInterfaceBridge): CollectCustomTelemetryProxy {
    override fun collect(name: String, value: String) {
        telemetryInterfaceBridge.telemetryCollect(name, value)
    }
}