package com.contentsquare.flutter.infrastructure.proxies

import com.contentsquare.flutter.infrastructure.bridges.TelemetryInterfaceBridge

/**
 * Allows to send the flutter to Contentsquare API.
 */
internal interface CollectXPFVersionProxy {
    /**
     * Collect the XPF version.
     *
     * @param version the XPF version
     */
    fun collect(version: String)

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [CollectXPFVersionProxy].
         */
        fun default(telemetryInterfaceBridge: TelemetryInterfaceBridge = TelemetryInterfaceBridge.default()): CollectXPFVersionProxy {
            return CollectXPFVersionProxyImpl(telemetryInterfaceBridge)
        }
    }
}

/**
 * An implementation of [CollectXPFVersionProxy].
 *
 * @see CollectXPFVersionProxy
 */
internal class CollectXPFVersionProxyImpl(private val telemetryInterfaceBridge: TelemetryInterfaceBridge): CollectXPFVersionProxy {
    override fun collect(version: String) {
        telemetryInterfaceBridge.telemetrySetXPFVersion(version)
        telemetryInterfaceBridge.telemetrySetXPFType("flutter")
    }
}