package com.contentsquare.flutter.infrastructure.proxies

import com.contentsquare.android.Contentsquare
import com.contentsquare.flutter.infrastructure.bridges.ContentsquareSDKBridge

/**
 * Allows to get the current session replay link from Contentsquare API.
 */
internal interface GetCurrentSessionReplayLinkProxy {
    /**
     * Get the current session replay link from contentsquare API.
     */
    fun getCurrentSessionReplayLink(): String?

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [GetCurrentSessionReplayLinkProxy].
         */
        fun default(contentsquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridge.getInstance()): GetCurrentSessionReplayLinkProxy {
            return GetCurrentSessionReplayLinkProxyImpl(contentsquareSDK = contentsquareSDK)
        }
    }
}

/**
 * An implementation of [GetCurrentSessionReplayLinkProxy].
 *
 * @see GetCurrentSessionReplayLinkProxy
 */
internal class GetCurrentSessionReplayLinkProxyImpl(private val contentsquareSDK: ContentsquareSDKBridge): GetCurrentSessionReplayLinkProxy {
    override fun getCurrentSessionReplayLink(): String? {
        val link = contentsquareSDK.currentSessionReplayLink()

        if (link == "INACTIVE") return null

        return link
    }
}