package com.contentsquare.flutter.infrastructure.proxies

import com.contentsquare.flutter.infrastructure.core.states.ContentsquarePluginState

internal interface GetStoredConfigProxy {

    /**
     * Get the stored config.
     */
    fun getConfig(): Map<String, Any?>

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [GetStoredConfigProxy].
         */
        fun default(featuresState: ContentsquarePluginState = ContentsquarePluginState): GetStoredConfigProxy {
            return GetStoredConfigProxyImpl(featuresState)
        }
    }
}

/**
 * An implementation of [GetStoredConfigProxy].
 *
 * @see GetStoredConfigProxy
 */
internal class GetStoredConfigProxyImpl(private val featuresState: ContentsquarePluginState) :
    GetStoredConfigProxy {
    override fun getConfig(): Map<String, Any?> {
        val srState = featuresState.getSessionReplayState()
        val containerViewIdState = featuresState.getContainerViewIdState()
        val pixelRatio = featuresState.getPixelRatioState()
        val apiErrorState = featuresState.getApiErrorsState()
        var crashReporterState = featuresState.getCrashReporterState()
        val featureFlagsState = featuresState.getFeatureFlagsState()
        val csInAppState = featuresState.getCsInAppState()

        return mapOf(
            ChannelConst.Key.ENABLE_SR to srState.value,
            // optional - only set when session replay is enabled
            ChannelConst.Key.CONTAINER_VIEW_ID to containerViewIdState.value,
            ChannelConst.Key.PIXEL_RATIO to pixelRatio.value,
            ChannelConst.Key.ENABLE_API_ERRORS to apiErrorState.value,
            ChannelConst.Key.ENABLE_CRASH_REPORTER to crashReporterState.value,
            ChannelConst.Key.FEATURE_FLAGS to featureFlagsState.value,
            ChannelConst.Key.ENABLE_CS_IN_APP to csInAppState.value,
        )
    }
}