package com.contentsquare.flutter.infrastructure.proxies

import com.contentsquare.android.Contentsquare
import com.contentsquare.flutter.infrastructure.bridges.ContentsquareSDKBridge

/**
 * Allows to get the user id from Contentsquare API.
 */
internal interface GetUserIdProxy {
    /**
     * Get the user id from contentsquare API.
     */
    fun getUserId(): String?

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [GetUserIdProxy].
         */
        fun default(contentsquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridge.getInstance()): GetUserIdProxy {
            return GetUserIdProxyImpl(contentsquareSDK = contentsquareSDK)
        }
    }
}

/**
 * An implementation of [GetUserIdProxy].
 *
 * @see GetUserIdProxy
 */
internal class GetUserIdProxyImpl(private val contentsquareSDK: ContentsquareSDKBridge): GetUserIdProxy {
    override fun getUserId(): String? {
        val userId = contentsquareSDK.getUserId()

        if (userId == "UNKNOWN") return null

        return userId
    }
}
