package com.contentsquare.flutter.infrastructure.proxies

import android.content.Context
import com.contentsquare.android.Contentsquare
import com.contentsquare.flutter.infrastructure.bridges.ContentsquareSDKBridge

/**
 * Allows to opt in to Contentsquare API.
 */
internal interface OptInProxy {
    /**
     * Opt in to contentsquare API.
     *
     * @param context the [Context] used to process opt in.
     */
    fun optIn(context: Context)

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [OptInProxy].
         */
        fun default(contentsquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridge.getInstance()): OptInProxy {
            return OptInProxyImpl(contentsquareSDK =contentsquareSDK)
        }
    }
}

/**
 * An implementation of [OptInProxy].
 *
 * @see OptInProxy
 */
internal class OptInProxyImpl(private val contentsquareSDK: ContentsquareSDKBridge): OptInProxy {
    override fun optIn(context: Context) {
        contentsquareSDK.optIn(context)
    }
}
