package com.contentsquare.flutter.infrastructure.proxies

import android.content.Context
import com.contentsquare.android.Contentsquare
import com.contentsquare.flutter.infrastructure.bridges.ContentsquareSDKBridge

/**
 * Allows to opt out to Contentsquare API.
 */
internal interface OptOutProxy {
    /**
     * Opt out to contentsquare API.
     *
     * @param context the [Context] used to process opt out.
     */
    fun optOut(context: Context)

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [OptOutProxy].
         */
        fun default(contentsquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridge.getInstance()): OptOutProxy {
            return OptOutProxyImpl(contentsquareSDK =contentsquareSDK)
        }
    }
}

/**
 * An implementation of [OptOutProxy].
 *
 * @see OptOutProxy
 */
internal class OptOutProxyImpl(private val contentsquareSDK: ContentsquareSDKBridge): OptOutProxy {
    override fun optOut(context: Context) {
        contentsquareSDK.optOut(context)
    }
}