package com.contentsquare.flutter.infrastructure.proxies

import com.contentsquare.android.Contentsquare
import com.contentsquare.flutter.infrastructure.bridges.ContentsquareSDKBridge

/**
 * Allows to resume tracking in Contentsquare API.
 */
internal interface ResumeTrackingProxy {
    /**
     * Calls resume tracking of contentsquare API.
     */
    fun resumeTracking()

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [ResumeTrackingProxy].
         */
        fun default(contentsquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridge.getInstance()): ResumeTrackingProxy {
            return ResumeTrackingProxyImpl(contentsquareSDK = contentsquareSDK)
        }
    }
}

/**
 * An implementation of [ResumeTrackingProxy].
 *
 * @see ResumeTrackingProxy
 */
internal class ResumeTrackingProxyImpl(private val contentsquareSDK: ContentsquareSDKBridge): ResumeTrackingProxy {
    override fun resumeTracking() {
        contentsquareSDK.resumeTracking()
    }
}