package com.contentsquare.flutter.infrastructure.proxies

import com.contentsquare.flutter.infrastructure.bridges.FlutterInterfaceBridge

/**
 * Allows to send crash reports to Contentsquare API.
 */
internal interface SendCrashReportProxy {
    /**
     * Send crash reports to contentsquare API.
     *
     * @param report list of data representation of FlutterThreadReport proto object
     */
    fun send(reports: List<ByteArray>);

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [SendCrashReportProxyImpl].
         */
        fun default(flutterInterfaceBridge: FlutterInterfaceBridge = FlutterInterfaceBridge.default()): SendCrashReportProxy {
            return SendCrashReportProxyImpl(flutterInterface = flutterInterfaceBridge)
        }
    }
}

/**
 * An implementation of [SendCrashReportProxy]
 *
 * @see SendCrashReportProxy
 */

internal class SendCrashReportProxyImpl(private val flutterInterface: FlutterInterfaceBridge) : SendCrashReportProxy {
    override fun send(reports: List<ByteArray>) {
        flutterInterface.sendCrashReports(reports)
    }

}