package com.contentsquare.flutter.infrastructure.proxies

import com.contentsquare.android.Contentsquare
import com.contentsquare.flutter.infrastructure.bridges.ContentsquareSDKBridge

/**
 * Allows to send a dynamic var to Contentsquare API.
 */
internal interface SendDynamicVarProxy {
    /**
     * Send the dynamic var to contentsquare API.
     *
     * @param variable the [ContentsquareDynamicVar] to send.
     */
    fun <T> send(variable: ContentsquareDynamicVar<T>)

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [SendDynamicVarProxy].
         */
        fun default(contentsquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridge.getInstance()): SendDynamicVarProxy {
            return SendDynamicVarProxyImpl(contentsquareSDK =contentsquareSDK)
        }
    }
}
/**
 * Represents the data send for a dynamic var to Contentsquare API.
 */
internal sealed class ContentsquareDynamicVar<T>(val key: String, val value: T)

/**
 * Represents the data send for an number dynamic var to Contentsquare API.
 */
internal class ContentsquareLongDynamicVar(value: Long, key: String): ContentsquareDynamicVar<Long>(key, value)

/**
 * Represents the data send for a string dynamic var to Contentsquare API.
 */
internal class ContentsquareStringDynamicVar(value: String, key: String): ContentsquareDynamicVar<String>(key, value)

/**
 * An implementation of [SendDynamicVarProxy].
 *
 * @see SendDynamicVarProxy
 */
internal class SendDynamicVarProxyImpl(private val contentsquareSDK: ContentsquareSDKBridge): SendDynamicVarProxy {
    override fun <T> send(variable: ContentsquareDynamicVar<T>) {
        when (variable) {
            is ContentsquareLongDynamicVar -> {
                contentsquareSDK.sendDynamicVar(variable.key, variable.value)
            }
            is ContentsquareStringDynamicVar -> {
                contentsquareSDK.sendDynamicVar(variable.key, variable.value)
            }
        }
    }
}
