package com.contentsquare.flutter.infrastructure.proxies

import com.contentsquare.flutter.infrastructure.bridges.FlutterInterfaceBridge

internal interface  SendSessionReplayEventProxy {

    /**
     * Send the session replay event to contentsquare Native SDK.
     *
     * @param sessionReplayEvent the session replay event to send.
     * @param pixelRatio the pixel ratio of the device
     */
    fun send(sessionReplayEvent: String, pixelRatio: Float)

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [SendSessionReplayEventProxy].
         */
        fun default(flutterInterfaceBridge: FlutterInterfaceBridge = FlutterInterfaceBridge.default()): SendSessionReplayEventProxy {
            return SendSessionReplayEventProxyImpl(flutterInterfaceBridge)
        }
    }
}

/**
 * An implementation of [SendSessionReplayEventProxy] that sends the session replay event
 * to the ContentSquare Native SDK.
 *
 * @see SendSessionReplayEventProxy
 */

internal class SendSessionReplayEventProxyImpl(private val flutterInterfaceBridge: FlutterInterfaceBridge) : SendSessionReplayEventProxy {
    override fun send(sessionReplayEvent: String, pixelRatio: Float) {
        flutterInterfaceBridge.sendSessionReplayEvent(sessionReplayEvent, pixelRatio)
    }
}