package com.contentsquare.flutter.infrastructure.proxies

import com.contentsquare.flutter.infrastructure.bridges.FlutterInterfaceBridge

/**
 * Allows to send a touch event to Contentsquare API.
 */
internal interface SendTouchEventProxy {
    /**
     * Send the touch event to contentsquare API.
     *
     * @param touchEvent the touch event to send.
     */
    fun send(touchEvent: String)

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [SendTouchEventProxy].
         */
        fun default(flutterInterfaceBridge: FlutterInterfaceBridge = FlutterInterfaceBridge.default()): SendTouchEventProxy {
            return SendTouchEventProxyImpl(flutterInterfaceBridge)
        }
    }
}

/**
 * An implementation of [SendTouchEventProxy] that sends the screen name to the Content Square API.
 *
 * @see SendTouchEventProxy
 */
internal class SendTouchEventProxyImpl(private val flutterInterfaceBridge: FlutterInterfaceBridge): SendTouchEventProxy {
    override fun send(touchEvent: String) {
        flutterInterfaceBridge.sendEvent(touchEvent)
    }
}
