package com.contentsquare.flutter.infrastructure.proxies

import com.contentsquare.android.Contentsquare
import com.contentsquare.android.api.model.Transaction
import com.contentsquare.flutter.infrastructure.bridges.ContentsquareSDKBridge

/**
 * Allows to send a transaction to Contentsquare API.
 */
internal interface SendTransactionProxy {
    /**
     * Send the transaction to contentsquare API.
     *
     * @param transaction the [ContentsquareTransaction] to send.
     */
    fun sendTransaction(transaction: ContentsquareTransaction)

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [SendTransactionProxy].
         */
        fun default(contentsquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridge.getInstance()): SendTransactionProxy {
            return SendTransactionProxyImpl(contentsquareSDK = contentsquareSDK)
        }
    }
}

/**
 * Represents the data send for a transaction to Contentsquare API.
 */
internal sealed class ContentsquareTransaction(val price: Float, val currency: String)

/**
 * Represents the data sent for a transaction without an ID to Contentsquare API.
 */
internal class ContentsquareTransactionWithoutID(price: Float, currency: String): ContentsquareTransaction(price, currency)

/**
 * Represents the data send for a transaction with an ID to Contentsquare API.
 */
internal class ContentsquareTransactionWithID(val id: String, price: Float, currency: String): ContentsquareTransaction(price, currency)

/**
 * An implementation of [SendTransactionProxy].
 *
 * @see SendTransactionProxy
 */
internal class SendTransactionProxyImpl(private val contentsquareSDK: ContentsquareSDKBridge): SendTransactionProxy {
    override fun sendTransaction(transaction: ContentsquareTransaction) {
        val transactionBuilder = Transaction.builder(transaction.price, transaction.currency)
        when (transaction) {
            is ContentsquareTransactionWithoutID -> {
            }
            is ContentsquareTransactionWithID -> {
                transactionBuilder.id(transaction.id)
            }
        }
        contentsquareSDK.sendTransaction(transactionBuilder.build())
    }

}