package com.contentsquare.flutter.infrastructure.proxies

import com.contentsquare.flutter.infrastructure.bridges.ContentsquareSDKBridge

/**
 * Allows to send a user identifier to Contentsquare API.
 */
internal interface SendUserIdentifierProxy {
    /**
     * Send the user identifier to contentsquare API.
     *
     * @param userIdentifier the user identifier to send.
     */
    fun send(userIdentifier: String);

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [SendUserIdentifierProxy].
         */
        fun default(contentsquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridge.getInstance()): SendUserIdentifierProxy {
            return SendUserIdentifierProxyImpl(contentsquareSDK = contentsquareSDK)
        }
    }
}

/**
 * An implementation of [SendUserIdentifierProxy] that sends the user
 * identifier to the Content Square API.
 *
 * @see SendUserIdentifierProxy
 */

internal class SendUserIdentifierProxyImpl(private val contentsquareSDK: ContentsquareSDKBridge) : SendUserIdentifierProxy {
    override fun send(userIdentifier: String) {
        contentsquareSDK.sendUserIdentifier(userIdentifier)
    }

}