package com.contentsquare.flutter.infrastructure.proxies

import com.contentsquare.flutter.infrastructure.bridges.ErrorAnalysisBridge

/**
 * Allows to set url masking patterns ErrorAnalysis API.
 */
internal interface SetURLMaskingPatternsProxy {
    /**
     * Set url masking patterns to ErrorAnalysis API.
     *
     * @param patterns the patterns that must be set.
     */
    fun setURLMaskingPatterns(patterns: List<String>)

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [SetURLMaskingPatternsProxy].
         */
        fun default(errorAnalysis: ErrorAnalysisBridge = ErrorAnalysisBridge.getInstance()): SetURLMaskingPatternsProxy {
            return SetURLMaskingPatternsProxyImpl(errorAnalysis = errorAnalysis)
        }
    }
}

/**
 * An implementation of [SetURLMaskingPatternsProxy].
 *
 * @see SetURLMaskingPatternsProxy
 */
internal class SetURLMaskingPatternsProxyImpl(private val errorAnalysis: ErrorAnalysisBridge): SetURLMaskingPatternsProxy {
    override fun setURLMaskingPatterns(patterns: List<String>) {
        errorAnalysis.setUrlMaskingPatterns(patterns)
    }
}