package com.contentsquare.flutter.infrastructure.proxies

import com.contentsquare.android.Contentsquare
import com.contentsquare.flutter.infrastructure.bridges.ContentsquareSDKBridge

/**
 * Allows to stop tracking in Contentsquare API.
 */
internal interface StopTrackingProxy {
    /**
     * Calls stop tracking of contentsquare API.
     */
    fun stopTracking()

    companion object Factory {
        /**
         * Creates a new instance of the default implementation of [StopTrackingProxy].
         */
        fun default(contentsquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridge.getInstance()): StopTrackingProxy {
            return StopTrackingProxyImpl(contentsquareSDK = contentsquareSDK)
        }
    }
}

/**
 * An implementation of [StopTrackingProxy].
 *
 * @see StopTrackingProxy
 */
internal class StopTrackingProxyImpl(private val contentsquareSDK: ContentsquareSDKBridge): StopTrackingProxy {
    override fun stopTracking() {
        contentsquareSDK.stopTracking()
    }
}