import ContentsquareModule

/// Bridge to error analysis module
protocol ErrorAnalysisBridge {
    /// Send api error to analysis
    ///
    /// - Parameter dict: the dictionnary of the api details
    func sendApiError(dict: [String : Any]) throws -> Void
    
    /// Set url masking patterns to ErrorAnalysis API.
    ///
    /// - Parameter patterns: the patterns that must be set.
    func setURLMaskingPatterns(patterns: [String]) throws -> Void
}

/// Factory creator class for [ErrorAnalysisBridge].
struct ErrorAnalysisBridgeFactory {

    /// Creates a new instance of the default implementation of [ErrorAnalysisBridge].
    static func makeDefault() -> ErrorAnalysisBridge {
        return ErrorAnalysisBridgeImpl()
    }
}

/// An implementation of [ErrorAnalysisBridge]
class ErrorAnalysisBridgeImpl: ErrorAnalysisBridge {
    func setURLMaskingPatterns(patterns: [String]) throws {
        ErrorAnalysis.setURLMaskingPatterns(patterns)
    }
    
    func sendApiError(dict: [String : Any]) throws {
        let httpMetrics = try DictionaryToHttpMetricConverter.convertFrom(dict: dict)
        // To be able to send the metric, we need to stop networkMetrics
        httpMetrics.stop();
    }
    
}
