import ContentsquareModule

/// Bridge to TelemetryInterface of contentsquare.
protocol TelemetryInterfaceBridge {
    /// Collect custom telemetry
    /// 
    /// - Parameter name: the name of the telemetry 
    /// - Parameter value: the value of the telemetry
    func telemetryCollect(name: String, value: String) throws -> Void
    
    /// Collect flutter version telemetry
    ///
    /// - Parameter version: the version of Flutter.
    func collectXPFVersion(version: String) throws -> Void
}

/// Factory creator class for [TelemetryInterfaceBridge].
struct TelemetryInterfaceBridgeFactory {

    /// Creates a new instance of the default implementation of [TelemetryInterfaceBridge].
    static func makeDefault() -> TelemetryInterfaceBridge {
        return TelemetryInterfaceBridgeImpl()
    }
}

/// An implementation of [TelemetryInterfaceBridge]
class TelemetryInterfaceBridgeImpl: TelemetryInterfaceBridge {
    func collectXPFVersion(version: String) throws {
        let selectorCollectXpfVersion = NSSelectorFromString("_telemetrySetXPFVersion:")
        if Contentsquare.self.responds(to: selectorCollectXpfVersion) {
            Contentsquare.perform(selectorCollectXpfVersion, with: version)
        }

        let selectorCollectXpfType = NSSelectorFromString("_telemetrySetXPFType:")
        if Contentsquare.self.responds(to: selectorCollectXpfType) {
            Contentsquare.perform(selectorCollectXpfType, with: "flutter")
        }
    }
    
    func telemetryCollect(name: String, value: String) throws {
        let selector = NSSelectorFromString("_telemetryCollect:withValue:")
        if Contentsquare.self.responds(to: selector) {
            Contentsquare.perform(selector, with: name, with: value)
        }
    }    
}
