/// `MethodCallAgent` used to execute custom telemetry collection.
class CollectCustomTelemetryAgent: MethodCallAgent {
    
    internal init(proxy: CollectCustomTelemetryProxy = CollectCustomTelemetryProxyFactory.makeDefault()) {
        self._proxy = proxy
    }
    
    /// Message to use in case of error during native call.
    static let exceptionMessage = "Exception occurred during collectCustomTelemetryData"
    
    /// Message in case of "value" parameter missing
    static let missingNameParameter =  "Missing String for the name parameter"
    
    /// Message in case of "name" parameter missing
    static let missingValueParameter = "Missing String for the value parameter"
    
    private let _proxy: CollectCustomTelemetryProxy
    
    var nativeExceptionMessage: String? {
        return CollectCustomTelemetryAgent.exceptionMessage
    }
    
    func execute(data: ExecutionData) throws -> ExecutionResponse {
        guard let arguments = data.call.arguments as? [String: Any],
              let name = arguments["name"] as? String else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument,
                message: CollectCustomTelemetryAgent.missingNameParameter,
                cause: nil
            )
        }
        
        guard let value = arguments["value"] as? String else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument,
                message: CollectCustomTelemetryAgent.missingValueParameter,
                cause: nil
            )
        }
        
        try _proxy.collect(name: name, value: value)
        
        return ExecutionResponse.succeed(result: nil)
    }
    
}
