/// `MethodCallAgent` used to execute flutter version telemetry collection.
class CollectXPFVersionAgent: MethodCallAgent {
    
    internal init(proxy: CollectXPFVersionProxy = CollectXPFVersionProxyFactory.makeDefault()) {
        self._proxy = proxy
    }
    
    /// Message to use in case of error during native call.
    static let exceptionMessage = "Exception occurred during \(MethodCallAgentMethod.collectXPFVersion.rawValue)"
    
    /// Message in case of "version" parameter missing
    static let missingVersionParameter =  "Missing String for the version parameter"
    
    private let _proxy: CollectXPFVersionProxy
    
    var nativeExceptionMessage: String? {
        return CollectXPFVersionAgent.exceptionMessage
    }
    
    func execute(data: ExecutionData) throws -> ExecutionResponse {
        guard let arguments = data.call.arguments as? [String: Any],
              let version = arguments["version"] as? String else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument,
                message: CollectXPFVersionAgent.missingVersionParameter,
                cause: nil
            )
        }
        
        try _proxy.collect(version: version)
        
        return ExecutionResponse.succeed(result: nil)
    }
    
}
