/// `SendCrashReportAgent` used to execute send crash report.
class SendCrashReportAgent: MethodCallAgent {
    
    internal init(proxy: SendCrashReportProxy = SendCrashReportProxyFactory.makeDefault()) {
        self._proxy = proxy
    }
    
    /// Message to use in case of error during native call.
    static let exceptionMessage = "Failed to send crash report"
    
    /// Message in case of "report" parameter missing
    static let missingReportMessage = "Missing data for report key"
    
    private let _proxy: SendCrashReportProxy
    
    var nativeExceptionMessage: String? {
        return SendCrashReportAgent.exceptionMessage
    }
    
    func execute(data: ExecutionData) throws -> ExecutionResponse {
        let arguments: [String: Any] = data.call.arguments as? [String: Any] ?? [:]
        guard let report = arguments["report"] as? FlutterStandardTypedData else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument, message: SendCrashReportAgent.missingReportMessage,
                cause: nil
            )
        }
        
        try _proxy.send(reports: [report.data])
        
        return ExecutionResponse.succeed(result: nil)
    }
}
