/// `MethodCallAgent` used to execute resume tracking
class SendDynamicVarAgent: MethodCallAgent {
    
    internal init(proxy: SendDynamicVarProxy = SendDynamicVarProxyFactory.makeDefault()) {
        self._proxy = proxy
    }
    
    /// Message to use in case of error during native call.
    static let exceptionMessage = "Error while sending the dynamic variable. Please make sure that you have defined the variable in the Contentsquare console"
    
    /// Message in case of "key" parameter missing
    static let missingKeyParameter =  "Missing string for the key parameter"
    
    /// Message in case of "stringValue" and  "intValue" parameter missing
    static let missingValueParameter =  "Either stringValue or intValue parameter should be provided"
    
    private let _proxy: SendDynamicVarProxy
    
    var nativeExceptionMessage: String? {
        return SendDynamicVarAgent.exceptionMessage
    }
    
    func execute(data: ExecutionData) throws -> ExecutionResponse {
        let arguments: [String : Any] = data.call.arguments as? [String : Any] ?? [:]
        
        guard let key = arguments["key"] as? String else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument,
                message: SendDynamicVarAgent.missingKeyParameter,
                cause: nil
            )
        }
        
        let stringValue = arguments["stringValue"] as? String ?? nil
        let intValue = arguments["intValue"] as? NSNumber ?? nil
        
        var dynamicVar: ContentsquareDynamicVar? = nil
        
        if (intValue != nil) {
            dynamicVar = ContentsquareDynamicVar.number(key: key, value: intValue!)
        } else if (stringValue != nil) {
            dynamicVar = ContentsquareDynamicVar.string(key: key, value: stringValue!)
        }
        
        if (dynamicVar == nil) {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument,
                message: SendDynamicVarAgent.missingValueParameter,
                cause: nil
            )
        }
        
        try _proxy.send(variable: dynamicVar!)
        
        return ExecutionResponse.succeed(result: nil)
    }
    
}
