/// `MethodCallAgent` used to execute send screen name.
class SendScreenNameAgent: MethodCallAgent {
    
    internal init(proxy: SendScreenNameProxy = SendScreenNameProxyFactory.makeDefault()) {
        self._proxy = proxy
    }
    
    /// Message to use in case of error during native call.
    static let exceptionMessage = "Exception occurred while sending screenName"
    
    /// Message in case of "screenName" parameter missing
    static let missingScreenNameParameter =  "Missing string for the screenName parameter"
    
    private let _proxy: SendScreenNameProxy
    
    var nativeExceptionMessage: String? {
        return SendScreenNameAgent.exceptionMessage
    }
    
    func execute(data: ExecutionData) throws -> ExecutionResponse {
        let arguments: [String : Any] = data.call.arguments as? [String : Any] ?? [:]
        guard let screenName = arguments["screenName"] as? String else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument,
                message: SendScreenNameAgent.missingScreenNameParameter,
                cause: nil
            )
        }
        
        var nativeCustomVars: [CustomVariable] = []
        if let customVars = arguments["customVars"] as? [[String: Any]] {
            nativeCustomVars = customVars.compactMap { customVar -> CustomVariable? in
                guard let index = customVar["index"] as? NSNumber,
                      let name = customVar["name"] as? String,
                      let value = customVar["value"] as? String else {
                    return nil
                }
                return CustomVariable(index: index, name: name, value: value)
            }
        }
        
        try _proxy.send(screenName: screenName, vars: nativeCustomVars)
        
        return ExecutionResponse.succeed(result: nil)
    }
    
}
