/// `MethodCallAgent` used to execute send session replay event.
class SendSessionReplayEventAgent: MethodCallAgent {
    
    internal init(proxy: SendSessionReplayEventProxy = SendSessionReplayEventProxyFactory.makeDefault()) {
        self._proxy = proxy
    }
    
    /// Message to use in case of error during native call.
    static let exceptionMessage = "Exception occurred during \(MethodCallAgentMethod.sendSessionReplayEvent.rawValue)"
    
    /// Message in case of "body" parameter missing
    static let missingBodyParameter =  "Missing Map for the body parameter"
    
    private let _proxy: SendSessionReplayEventProxy
    
    var nativeExceptionMessage: String? {
        return SendSessionReplayEventAgent.exceptionMessage
    }
    
    func execute(data: ExecutionData) throws -> ExecutionResponse {
        let arguments: [String : Any] = data.call.arguments as? [String : Any] ?? [:]
        
        guard let body = arguments["body"] as? [String: Any] else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument,
                message: SendSessionReplayEventAgent.missingBodyParameter,
                cause: nil
            )
        }
        
        try _proxy.sendSessionReplayEvent(ofValue: body)
        
        return ExecutionResponse.succeed(result: nil)
    }
    
}
