/// `MethodCallAgent` used to execute send session replay event as proto
// TODO: rename this class to SendSessionReplayEventAgent in FLUT-1211
class SendSessionReplayEventAsProtoAgent: MethodCallAgent {
    
    internal init(proxy: SendSessionReplayEventAsProtoProxy = SendSessionReplayEventAsProtoProxyFactory.makeDefault()) {
        self._proxy = proxy
    }
    
    /// Message to use in case of error during native call.
    static let exceptionMessage = "Exception occurred during \(MethodCallAgentMethod.sendSessionReplayAsProtoEvent.rawValue)"
    
    /// Message in case of "event" parameter missing
    static let missingDataParameter =  "Missing Data array for the events parameter"
    
    private let _proxy: SendSessionReplayEventAsProtoProxy
    
    var nativeExceptionMessage: String? {
        return SendSessionReplayEventAsProtoAgent.exceptionMessage
    }
    
    func execute(data: ExecutionData) throws -> ExecutionResponse {
        let arguments: [String: Any] = data.call.arguments as? [String: Any] ?? [:]
        guard let event = arguments["data"] as? FlutterStandardTypedData else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument, message: SendSessionReplayEventAsProtoAgent.missingDataParameter,
                cause: nil
            )
        }
        
        try _proxy.sendSessionReplayEvent(ofValue: [event.data])
        
        return ExecutionResponse.succeed(result: nil)
    }
    
}
