/// `MethodCallAgent` used to execute send touch event.
class SendTouchEventAgent: MethodCallAgent {
    
    internal init(proxy: SendTouchEventProxy = SendTouchEventProxyFactory.makeDefault()) {
        self._proxy = proxy
    }
    
    /// Message to use in case of error during native call.
    static let exceptionMessage = "Exception occurred during \(MethodCallAgentMethod.sendTouchEvent.rawValue)"
    
    /// Message in case of "body" parameter missing
    static let missingBodyParameter =  "Missing string for the body parameter"
    
    private let _proxy: SendTouchEventProxy
    
    var nativeExceptionMessage: String? {
        return SendTouchEventAgent.exceptionMessage
    }
    
    func execute(data: ExecutionData) throws -> ExecutionResponse {
        let arguments: [String : Any] = data.call.arguments as? [String : Any] ?? [:]
        
        guard let body = arguments["body"] as? String else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument,
                message: SendTouchEventAgent.missingBodyParameter,
                cause: nil
            )
        }
        
        try _proxy.sendTouchEvent(ofValue: body)
        
        return ExecutionResponse.succeed(result: nil)
    }
    
}
