/// `MethodCallAgent` used to execute send transaction.
class SendTransactionAgent: MethodCallAgent {
    internal init(proxy: SendTransactionProxy = SendTransactionProxyFactory.makeDefault()) {
        self._proxy = proxy
    }
    
    /// Message to use in case of error during native call.
    static let exceptionMessage = "Exception occurred while sending transaction"
    
    /// Message in case of "price" parameter missing
    static let missingPriceParameter =  "Missing double for the price parameter"
    
    /// Message in case of "currency" parameter missing
    static let missingCurrencyParameter =  "Missing string for the currency parameter"
    
    private let _proxy: SendTransactionProxy
    
    var nativeExceptionMessage: String? {
        return SendTransactionAgent.exceptionMessage
    }
    
    func execute(data: ExecutionData) throws -> ExecutionResponse {
        let arguments: [String : Any] = data.call.arguments as? [String : Any] ?? [:]
        
        let transactionId = arguments["transactionId"] as? String ?? nil
        guard let priceNumber = arguments["price"] as? NSNumber else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument,
                message: SendTransactionAgent.missingPriceParameter,
                cause: nil
            )
        }
        let price = priceNumber.floatValue
        
        guard let currency = arguments["currency"] as? String else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument,
                message: SendTransactionAgent.missingCurrencyParameter,
                cause: nil
            )
        }
        
        try _proxy.sendTransaction(
            transaction: ContentsquareTransaction(price: price, currency: currency, id: transactionId)
        )
        
        return ExecutionResponse.succeed(result: nil)
    }
    
}
