/// `SendUserIdentifierAgent` used to execute send user identifier.
class SendUserIdentifierAgent: MethodCallAgent {
    
    internal init(proxy: SendUserIdentifierProxy = SendUserIdenfierProxyFactory.makeDefault()) {
        self._proxy = proxy
    }
    
    /// Message to use in case of error during native call.
    static let exceptionMessage = "Failed to send user identifier"
    
    /// Message in case of "userIdentifier" parameter missing
    static let missingUserIdentifierMessage = "Missing string for the userIdentifier parameter"
    
    private let _proxy: SendUserIdentifierProxy
    
    var nativeExceptionMessage: String? {
        return SendUserIdentifierAgent.exceptionMessage
    }
    
    func execute(data: ExecutionData) throws -> ExecutionResponse {
        let arguments: [String: Any] = data.call.arguments as? [String: Any] ?? [:]
        guard let userIdentifier = arguments["userIdentifier"] as? String else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument, message: SendUserIdentifierAgent.missingUserIdentifierMessage,
                cause: nil
            )
        }
        
        try _proxy.send(userIdentifier: userIdentifier)
        
        return ExecutionResponse.succeed(result: nil)
    }
}
