/// `MethodCallAgent`used to execute set URL Masking patterns.
class SetURLMaskingPatternsAgent: MethodCallAgent {
    
    internal init(proxy: SetURLMaskingPatternsProxy = SetURLMaskingPatternsProxyFactory.makeDefault()) {
        self._proxy = proxy
    }
    
    /// Message to use in case of error during native call.
    static let exceptionMessage = "Exception occurred during \(MethodCallAgentMethod.setURLMaskingPatterns.rawValue)"
    
    /// Message in case of "patterns" parameter missing
    static let missingPatternsParameter = "Missing String array for the patterns parameter"
    
    private let _proxy: SetURLMaskingPatternsProxy
    
    var nativeExceptionMessage: String? {
        return SetURLMaskingPatternsAgent.exceptionMessage
    }
    
    func execute(data: ExecutionData) throws -> ExecutionResponse {
        guard let arguments = data.call.arguments as? [String: Any],
              let patterns = arguments["patterns"] as? [String] else {
            throw FailedExecutionError(
                reason: FailedExecutionResponseReason.missingArgument,
                message: SetURLMaskingPatternsAgent.missingPatternsParameter,
                cause: nil
            )
        }
        
        try _proxy.setURLMaskingPatterns(patterns: patterns)
        
        return ExecutionResponse.succeed(result: nil)
    }
    
}
