/// Used to execute the difference method from `FlutterMethodCall`.
class MethodCallExecutor {

  /// Proceeds with the execution by the agent and pass the response in the result.
  ///
  /// - Parameter agent: the `MethodCallAgent` used to execute the data
  /// - Parameter data: the `ExecutionData` that will be executed by the agent
  /// - Parameter result: the `FlutterResult` used to pass the response of the execution by the agent
  func execute(agent: MethodCallAgent, data: ExecutionData, result: FlutterResult) {
    let response = agent.safeExecute(data: data)
    switch response {
    case .notAvailable(method: _, data: _):
      result(FlutterMethodNotImplemented)
    case .failed(let reason, let message, let cause):
      result(FlutterError(code: reason.rawValue, message: message, details: cause))
    case .succeed(result: let succeedResult):
      result(succeedResult)
    }
  }
}
