/// Reason of failure of an execution.
enum FailedExecutionResponseReason: String {
    case missingArgument = "MISSING_ARGUMENT"
    case nativeException = "NATIVE_EXCEPTION"
    case dynamicVarError = "DYNAMIC_VAR_ERROR"
    case invalidURL = "INVALID_URL"
    case invalidData = "INVALID_DATA"
    case unexpectedError = "UNEXPECTED_ERROR"
}

/// Response of an execution from an execution
enum ExecutionResponse: Equatable {
    case succeed(result: Any?)
    case notAvailable(method: String, data: ExecutionData)
    case failed(reason: FailedExecutionResponseReason, message: String?, cause: Any?)
    
    static func ==(lhs: ExecutionResponse, rhs: ExecutionResponse) -> Bool {
        switch (lhs, rhs) {
        case let (.succeed(lhsResult), .succeed(rhsResult)):
            if ((lhsResult == nil && rhsResult != nil) || (lhsResult != nil && rhsResult == nil)) {
                return false
            } else if (lhsResult == nil && rhsResult == nil) {
                return true
            }
            return lhsResult.customMirror.subjectType == rhsResult.customMirror.subjectType && "\(lhsResult ?? "")" == "\(rhsResult ?? "")"
        case let (.notAvailable(lhsMethod, lhsData), .notAvailable(rhsMethod, rhsData)):
            return lhsMethod == rhsMethod && lhsData.call == rhsData.call
        case let (.failed(lhsReason, lhsMessage, lhsCause), .failed(rhsReason, rhsMessage, rhsCause)):
            var causeEquals = false
            if (rhsCause == nil && lhsCause == nil) {
                causeEquals = true
            } else if (rhsCause != nil && lhsCause != nil) {
                causeEquals = rhsCause.customMirror.subjectType == lhsCause.customMirror.subjectType && "\(lhsCause!)" == "\(rhsCause!)"
            }
            return lhsReason.rawValue == rhsReason.rawValue && lhsMessage == rhsMessage && causeEquals
        default:
            return false
        }
    }
}
