/// A provider of the [UIView] that represents the Flutter root view.
protocol FlutterRootViewProvider: AnyObject {
    
    /// Get the Flutter root view
    func getView() -> UIView?
}

/// An implementation of [FlutterRootViewProvider] that uses [UIApplication]
/// to provide the Flutter root view.
class UIApplicationFlutterRootViewProvider: FlutterRootViewProvider {
    weak var rootViewController: FlutterViewController?
    
    init(application: UIApplication) {
        rootViewController = application.delegate?.window??.rootViewController as? FlutterViewController
    }
    
    init(flutterViewController: FlutterViewController) {
        rootViewController = flutterViewController
    }
    
    func getView() -> UIView? {
        return rootViewController?.view
    }
}
