/// Allows to collect custom telemetry the flutter to Contentsquare API.
protocol CollectCustomTelemetryProxy {
    /// Collect custom telemetry.
    /// 
    /// - Parameter name: the name of the telemetry 
    /// - Parameter value: the value of the telemetry
    func collect(name: String, value: String) throws -> Void
}

/// Factory creator class for [CollectCustomTelemetryProxy].
struct CollectCustomTelemetryProxyFactory {

    /// Creates a new instance of the default implementation of [CollectCustomTelemetryProxy].
    static func makeDefault(telemetryInterfaceBridge: TelemetryInterfaceBridge = TelemetryInterfaceBridgeFactory.makeDefault()) -> CollectCustomTelemetryProxy {
        return CollectCustomTelemetryProxyImpl(telemetryInterfaceBridge: telemetryInterfaceBridge)
    }
}

/// An implementation of [CollectCustomTelemetryProxy]
class CollectCustomTelemetryProxyImpl: CollectCustomTelemetryProxy {
    private let _telemetryInterfaceBridge: TelemetryInterfaceBridge

    init(telemetryInterfaceBridge: TelemetryInterfaceBridge) {
        _telemetryInterfaceBridge = telemetryInterfaceBridge
    }

    func collect(name: String, value: String) throws {
        try _telemetryInterfaceBridge.telemetryCollect(name: name, value: value)
    }    
}
