/// Allows to collect custom telemetry the flutter to Contentsquare API.
protocol CollectXPFVersionProxy {
    /// Collect the flutter version.
    ///
    /// - Parameter version: the flutter version to collect.
    func collect(version: String) throws -> Void
}

/// Factory creator class for [CollectXPFVersionProxy].
struct CollectXPFVersionProxyFactory {

    /// Creates a new instance of the default implementation of [CollectXPFVersionProxy].
    static func makeDefault(telemetryInterfaceBridge: TelemetryInterfaceBridge = TelemetryInterfaceBridgeFactory.makeDefault()) -> CollectXPFVersionProxy {
        return CollectXPFVersionProxyImpl(telemetryInterfaceBridge: telemetryInterfaceBridge)
    }
}

/// An implementation of [CollectXPFVersionProxy]
class CollectXPFVersionProxyImpl: CollectXPFVersionProxy {
    private let _telemetryInterfaceBridge: TelemetryInterfaceBridge

    init(telemetryInterfaceBridge: TelemetryInterfaceBridge) {
        _telemetryInterfaceBridge = telemetryInterfaceBridge
    }

    func collect(version: String) throws {
        try _telemetryInterfaceBridge.collectXPFVersion(version: version)
    }
}
