/// Allows to opt out to Contentsquare API.
protocol ForgetMeProxy {
    /// Calls forget me of contentsquare API.
    func forgetMe() throws -> Void
}

/// Factory creator class for [ForgetMeProxy].
struct ForgetMeProxyFactory {

    /// Creates a new instance of the default implementation of [ForgetMeProxy].
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    static func makeDefault(contensquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridgeFactory.getInstance()) -> ForgetMeProxy {
        return ForgetMeProxyImpl(contensquareSDK: contensquareSDK)
    }
}

/// An implementation of [ForgetMeProxy]
class ForgetMeProxyImpl: ForgetMeProxy {
    
    private let _contensquareSDK: ContentsquareSDKBridge
    
    /// Creates a new instance of `ForgetMeProxyImpl`
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    internal init(contensquareSDK: ContentsquareSDKBridge) {
        self._contensquareSDK = contensquareSDK
    }
    
    func forgetMe() throws {
        try _contensquareSDK.forgetMe()
    }
}

