/// Allows to get the current session replay link from Contentsquare API.
protocol GetCurrentSessionReplayLinkProxy {
    /// Get the current session replay link from contentsquare API.
    func getCurrentSessionReplayLink() throws -> String?
}

/// Factory creator class for [GetCurrentSessionReplayLinkProxy].
struct GetCurrentSessionReplayLinkProxyFactory {

    /// Creates a new instance of the default implementation of [GetCurrentSessionReplayLinkProxy].
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    static func makeDefault(contensquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridgeFactory.getInstance()) -> GetCurrentSessionReplayLinkProxy {
        return GetCurrentSessionReplayLinkProxyImpl(contensquareSDK: contensquareSDK)
    }
}


/// An implementation of [GetCurrentSessionReplayLinkProxy]
class GetCurrentSessionReplayLinkProxyImpl: GetCurrentSessionReplayLinkProxy {
    
    private let _contensquareSDK: ContentsquareSDKBridge
    
    /// Creates a new instance of `GetCurrentSessionReplayLinkProxyImpl`
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    internal init(contensquareSDK: ContentsquareSDKBridge) {
        self._contensquareSDK = contensquareSDK
    }
    
    func getCurrentSessionReplayLink() throws -> String? {
        return try _contensquareSDK.getCurrentSessionReplayLink()?.absoluteString
    }
}
