/// Allows to get the user id from Contentsquare API.
protocol GetUserIdProxy {
    /// Get the user id from contentsquare API.
    func getUserId() throws -> String?
}

/// Factory creator class for [GetUserIdProxy].
struct GetUserIdProxyFactory {

    /// Creates a new instance of the default implementation of [GetUserIdProxy].
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    static func makeDefault(contensquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridgeFactory.getInstance()) -> GetUserIdProxy {
        return GetUserIdProxyImpl(contensquareSDK: contensquareSDK)
    }
}

/// An implementation of [GetUserIdProxy]
class GetUserIdProxyImpl: GetUserIdProxy {
    
    private let _contensquareSDK: ContentsquareSDKBridge
    
    /// Creates a new instance of `GetUserIdProxyImpl`
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    internal init(contensquareSDK: ContentsquareSDKBridge) {
        self._contensquareSDK = contensquareSDK
    }
    
    func getUserId() throws -> String? {
        return try _contensquareSDK.getUserID()
    }
}
