import ContentsquareModule

/// Allows to opt in to Contentsquare API.
protocol OptInProxy {
    /// Opt in to contentsquare API.
    func optIn() throws -> Void
}

/// Factory creator class for [OptInProxy].
struct OptInProxyFactory {

    /// Creates a new instance of the default implementation of [OptInProxy].
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    static func makeDefault(contensquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridgeFactory.getInstance()) -> OptInProxy {
        return OptInProxyImpl(contensquareSDK: contensquareSDK)
    }
}

/// An implementation of [OptInProxy]
class OptInProxyImpl: OptInProxy {
    
    private let _contensquareSDK: ContentsquareSDKBridge
    
    /// Creates a new instance of `OptInProxyImpl`
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    internal init(contensquareSDK: ContentsquareSDKBridge) {
        self._contensquareSDK = contensquareSDK
    }
    
    func optIn() throws {
        try _contensquareSDK.optIn()
    }    
}
