import ContentsquareModule

/// Allows to opt out to Contentsquare API.
protocol OptOutProxy {
    /// Opt out to contentsquare API.
    func optOut() throws -> Void
}

/// Factory creator class for [OptOutProxy].
struct OptOutProxyFactory {

    /// Creates a new instance of the default implementation of [OptOutProxy].
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    static func makeDefault(contensquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridgeFactory.getInstance()) -> OptOutProxy {
        return OptOutProxyImpl(contensquareSDK: contensquareSDK)
    }
}

/// An implementation of [OptOutProxy]
class OptOutProxyImpl: OptOutProxy {
    
    private let _contensquareSDK: ContentsquareSDKBridge
    
    /// Creates a new instance of `OptOutProxyImpl`
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    internal init(contensquareSDK: ContentsquareSDKBridge) {
        self._contensquareSDK = contensquareSDK
    }
    
    func optOut() throws {
        try _contensquareSDK.optOut()
    }    
}
