/// Allows to resume tracking in Contentsquare API.
protocol ResumeTrackingProxy {
    /// Calls resume tracking of contentsquare API.
    func resumeTracking() throws -> Void
}

/// Factory creator class for [ResumeTrackingProxy].
struct ResumeTrackingProxyFactory {

    /// Creates a new instance of the default implementation of [ResumeTrackingProxy].
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    static func makeDefault(contensquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridgeFactory.getInstance()) -> ResumeTrackingProxy {
        return ResumeTrackingProxyImpl(contensquareSDK: contensquareSDK)
    }
}

/// An implementation of [ResumeTrackingProxy]
class ResumeTrackingProxyImpl: ResumeTrackingProxy {
    
    private let _contensquareSDK: ContentsquareSDKBridge
    
    /// Creates a new instance of `ResumeTrackingProxyImpl`
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    internal init(contensquareSDK: ContentsquareSDKBridge) {
        self._contensquareSDK = contensquareSDK
    }
    
    func resumeTracking() throws {
        try _contensquareSDK.resumeTracking()
    }
}
