/// Allows to send api errors to Contentsquare API.
protocol SendApiErrorProxy {
    /// Send the api errors to contentsquare API.
    func sendApiError(ofValue arguments: [String : Any]) throws -> Void
}

/// Factory creator class for [SendApiErrorProxy].
struct SendApiErrorProxyFactory {

    /// Creates a new instance of the default implementation of [SendApiErrorProxy].
    ///
    /// - Parameter errorAnalysis: The `ErrorAnalysisBridge` used to access error analysis API of contentsquare.
    static func makeDefault(errorAnalysis: ErrorAnalysisBridge = ErrorAnalysisBridgeFactory.makeDefault()) -> SendApiErrorProxy {
        return SendApiErrorProxyImpl(errorAnalysis: errorAnalysis)
    }
}

/// An implementation of [SendApiErrorProxy]
class SendApiErrorProxyImpl: SendApiErrorProxy {
    
    private let _errorAnalysis: ErrorAnalysisBridge
    
    /// Creates a new instance of `SendApiErrorProxyImpl`
    ///
    /// - Parameter errorAnalysis: The `ErrorAnalysisBridge` used to access error analysis API of contentsquare.
    internal init(errorAnalysis: ErrorAnalysisBridge) {
        self._errorAnalysis = errorAnalysis
    }
    
    func sendApiError(ofValue arguments: [String : Any]) throws {
        try _errorAnalysis.sendApiError(dict: arguments)
    }
    
}
