import ContentsquareModule

/// Allows to send a crash report to Contentsquare API.
protocol SendCrashReportProxy {
    /// Send a crash report to contentsquare API.
    ///
    /// - Parameter reports: list of data representation of FlutterThreadReport proto object
    func send(reports: [Data]) throws -> Void
}

/// Factory creator class for [SendCrashReportProxy].
struct SendCrashReportProxyFactory {
    
    /// Creates a new instance of the default implementation of [SendCrashReportProxy].
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    static func makeDefault(contentsquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridgeFactory.getInstance()) -> SendCrashReportProxy {
        return SendCrashReportProxyImpl(contentsquareSDK: contentsquareSDK)
    }
}

/// An implementation of [SendCrashReportProxy]
class SendCrashReportProxyImpl: SendCrashReportProxy {
    // document
    
    private let _contentsquareSDK: ContentsquareSDKBridge
    
    /// Creates a new instance of `SendCrashReportProxyImpl`
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    internal init(contentsquareSDK: ContentsquareSDKBridge) {
        self._contentsquareSDK = contentsquareSDK
    }
    
    func send(reports: [Data]) throws {
        try _contentsquareSDK.sendFlutterCrashReports(reports: reports)
    }
}
