import ContentsquareModule

/// Allows to send a dynamic var to Contentsquare API.
protocol SendDynamicVarProxy {
    /// Send the dynamic var to contentsquare API.
    ///
    /// - Parameter variable: the `ContentsquareDynamicVar`to send.
    func send(variable: ContentsquareDynamicVar) throws -> Void
}

/// Represents the data send for a dynamic var to Contentsquare API.
enum ContentsquareDynamicVar {
    case string(key: String, value: String)
    case number(key: String, value: NSNumber)
}

/// Factory creator class for [SendDynamicVarProxy].
struct SendDynamicVarProxyFactory {

    /// Creates a new instance of the default implementation of [SendDynamicVarProxy].
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    static func makeDefault(contensquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridgeFactory.getInstance()) -> SendDynamicVarProxy {
        return SendDynamicVarProxyImpl(contensquareSDK: contensquareSDK)
    }
}

/// An implementation of [SendDynamicVarProxy]
class SendDynamicVarProxyImpl: SendDynamicVarProxy {
    
    private let _contensquareSDK: ContentsquareSDKBridge
    
    /// Creates a new instance of `Se   ndTransactionProxyImpl`
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    internal init(contensquareSDK: ContentsquareSDKBridge) {
        self._contensquareSDK = contensquareSDK
    }
    
    func send(variable: ContentsquareDynamicVar) throws {
        switch (variable) {
        case .number(key: let key, value: let value):
            try _contensquareSDK.sendDynamicVar(dynamicVar: DynamicVar(key: key, value: value.uint32Value))
        case .string(key: let key, value: let value):
            try _contensquareSDK.sendDynamicVar(dynamicVar: DynamicVar(key: key, value: value))
        }
        
    }
}
