/// Allows to send a session replay event as proto data to Contentsquare API.
// TODO: to be renamed to SendSessionReplayEventProxy in FLUT-1211
protocol SendSessionReplayEventAsProtoProxy {
    /// Send the session replay event to contentsquare API.
    func sendSessionReplayEvent(ofValue events: [Data]) throws -> Void
}

/// Factory creator class for [SendSessionReplayEventAsProtoProxyFactory].
struct SendSessionReplayEventAsProtoProxyFactory {

    /// Creates a new instance of the default implementation of [SendSessionReplayEventAsProtoProxyFactory].
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    static func makeDefault(contensquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridgeFactory.getInstance()) -> SendSessionReplayEventAsProtoProxy {
        return SendSessionReplayEventAsProtoProxyImpl(contensquareSDK: contensquareSDK)
    }
}

/// An implementation of [SendSessionReplayEventAsProtoProxyFactory]
class SendSessionReplayEventAsProtoProxyImpl: SendSessionReplayEventAsProtoProxy {
    
    private let _contensquareSDK: ContentsquareSDKBridge
    
    /// Creates a new instance of `SendSessionReplayEventAsProtoProxyImpl`
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    internal init(contensquareSDK: ContentsquareSDKBridge) {
        self._contensquareSDK = contensquareSDK
    }
    
    func sendSessionReplayEvent(ofValue events: [Data]) throws {
        try _contensquareSDK.sendSessionReplayEvent(events: events)
    }
    
}
