/// Allows to send a session replay event to Contentsquare API.
protocol SendSessionReplayEventProxy {
    /// Send the session replay event to contentsquare API.
    func sendSessionReplayEvent(ofValue body: [String: Any]) throws -> Void
}

/// Factory creator class for [SendSessionReplayEventProxy].
struct SendSessionReplayEventProxyFactory {

    /// Creates a new instance of the default implementation of [SendSessionReplayEventProxy].
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    static func makeDefault(contensquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridgeFactory.getInstance()) -> SendSessionReplayEventProxy {
        return SendSessionReplayEventProxyImpl(contensquareSDK: contensquareSDK)
    }
}

/// An implementation of [SendSessionReplayEventProxy]
class SendSessionReplayEventProxyImpl: SendSessionReplayEventProxy {
    
    private let _contensquareSDK: ContentsquareSDKBridge
    
    /// Creates a new instance of `SendSessionReplayEventProxyImpl`
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    internal init(contensquareSDK: ContentsquareSDKBridge) {
        self._contensquareSDK = contensquareSDK
    }
    
    func sendSessionReplayEvent(ofValue body: [String: Any]) throws {
        try _contensquareSDK.sendSessionReplayEvent(body: body)
    }
    
}
