/// Allows to send a touch event to Contentsquare API.
protocol SendTouchEventProxy {
    /// Send the touch event to contentsquare API.
    func sendTouchEvent(ofValue body: String) throws -> Void
}

/// Factory creator class for [SendTouchEventProxy].
struct SendTouchEventProxyFactory {

    /// Creates a new instance of the default implementation of [SendTouchEventProxy].
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    static func makeDefault(contensquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridgeFactory.getInstance()) -> SendTouchEventProxy {
        return SendTouchEventProxyImpl(contensquareSDK: contensquareSDK)
    }
}

/// An implementation of [SendTouchEventProxy]
class SendTouchEventProxyImpl: SendTouchEventProxy {
    
    private let _contensquareSDK: ContentsquareSDKBridge
    
    /// Creates a new instance of `SendTouchEventProxyImpl`
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    internal init(contensquareSDK: ContentsquareSDKBridge) {
        self._contensquareSDK = contensquareSDK
    }
    
    func sendTouchEvent(ofValue body: String) throws {
        try _contensquareSDK.sendTouchEvent(body: body)
    }
    
}
