import ContentsquareModule

/// Allows to send a transaction to Contentsquare API.
protocol SendTransactionProxy {
    /// Send the transaction to contentsquare API.
    ///
    /// - Parameter transaction: the [ContentsquareTransaction] to send.
    func sendTransaction(transaction: ContentsquareTransaction) throws -> Void
}

/// Represents the data send for a transaction to Contentsquare API.
class ContentsquareTransaction {
    let price: Float
    let currency: String
    let id: String?
    
    /// Creates a new instance of [CustomVariable]
    ///
    /// - Parameter price: The price of the transaction
    /// - Parameter currency: The currency of the `price` of the transaction
    /// - Parameter id: The identifier of the transaction
    internal init(price: Float, currency: String, id: String? = nil) {
        self.price = price
        self.currency = currency
        self.id = id
    }
}

/// Factory creator class for [SendTransactionProxy].
struct SendTransactionProxyFactory {

    /// Creates a new instance of the default implementation of [SendTransactionProxy].
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    static func makeDefault(contensquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridgeFactory.getInstance()) -> SendTransactionProxy {
        return SendTransactionProxyImpl(contensquareSDK: contensquareSDK)
    }
}

/// An implementation of [SendTransactionProxy]
class SendTransactionProxyImpl: SendTransactionProxy {
    
    private let _contensquareSDK: ContentsquareSDKBridge
    
    /// Creates a new instance of `SendTransactionProxyImpl`
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    internal init(contensquareSDK: ContentsquareSDKBridge) {
        self._contensquareSDK = contensquareSDK
    }
    
    func sendTransaction(transaction: ContentsquareTransaction) throws {
        let customerTransaction = CustomerTransaction(id: transaction.id, value: transaction.price, currency: transaction.currency)
        
        try _contensquareSDK.sendTransaction(transaction: customerTransaction)
    }
    
}
