import ContentsquareModule

/// Allows to send a user identifier to Contentsquare API.
protocol SendUserIdentifierProxy {
    /// Send a user identifier to contentsquare API.
    ///
    /// - Parameter userIdentifier: user identifier screen to send
    func send(userIdentifier: String) throws -> Void
}

/// Factory creator class for [SendUserIdentifierProxy].
struct SendUserIdenfierProxyFactory {
    
    /// Creates a new instance of the default implementation of [SendUserIdentifierProxy].
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    static func makeDefault(contentsquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridgeFactory.getInstance()) -> SendUserIdentifierProxy {
        return SendUserIdentifierProxyImpl(contentsquareSDK: contentsquareSDK)
    }
}

/// An implementation of [SendUserIdentifierProxy]
class SendUserIdentifierProxyImpl: SendUserIdentifierProxy {
    // document
    
    private let _contentsquareSDK: ContentsquareSDKBridge
    
    /// Creates a new instance of `SendUserIdentifierProxyImpl`
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    internal init(contentsquareSDK: ContentsquareSDKBridge) {
        self._contentsquareSDK = contentsquareSDK
    }
    
    func send(userIdentifier: String) throws {
        try _contentsquareSDK.sendUserIdentifier(named: userIdentifier)
    }
}
