/// Allows to set url masking patterns ErrorAnalysis API.
protocol SetURLMaskingPatternsProxy {
    /// Set url masking patterns to ErrorAnalysis API.
    ///
    /// - Parameter patterns: the patterns that must be set.
    func setURLMaskingPatterns(patterns: [String]) throws -> Void
}

/// Factory creator class for [SetURLMaskingPatternsProxy].
struct SetURLMaskingPatternsProxyFactory {

    /// Creates a new instance of the default implementation of [SetURLMaskingPatternsProxy].
    ///
    /// - Parameter errorAnalysis: The `ErrorAnalysisBridge` used to access error analysis API of contentsquare.
    static func makeDefault(errorAnalysis: ErrorAnalysisBridge = ErrorAnalysisBridgeFactory.makeDefault()) -> SetURLMaskingPatternsProxy {
        return SetURLMaskingPatternsProxyImpl(errorAnalysis: errorAnalysis)
    }
}


/// An implementation of [SetURLMaskingPatternsProxy]
class SetURLMaskingPatternsProxyImpl: SetURLMaskingPatternsProxy {
    
    private let _errorAnalysis: ErrorAnalysisBridge
    
    /// Creates a new instance of `SetURLMaskingPatternsProxyImpl`
    ///
    /// - Parameter errorAnalysis: The `ErrorAnalysisBridge` used to access error analysis API of contentsquare.
    internal init(errorAnalysis: ErrorAnalysisBridge) {
        self._errorAnalysis = errorAnalysis
    }
    
    func setURLMaskingPatterns(patterns: [String]) throws {
        try _errorAnalysis.setURLMaskingPatterns(patterns: patterns)
    }
    
}
