/// Allows to stop tracking in Contentsquare API.
protocol StopTrackingProxy {
    /// Calls stop tracking of contentsquare API.
    func stopTracking() throws -> Void
}

/// Factory creator class for [StopTrackingProxy].
struct StopTrackingProxyFactory {

    /// Creates a new instance of the default implementation of [StopTrackingProxy].
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    static func makeDefault(contensquareSDK: ContentsquareSDKBridge = ContentsquareSDKBridgeFactory.getInstance()) -> StopTrackingProxy {
        return StopTrackingProxyImpl(contensquareSDK: contensquareSDK)
    }
}

/// An implementation of [StopTrackingProxy]
class StopTrackingProxyImpl: StopTrackingProxy {
    
    private let _contensquareSDK: ContentsquareSDKBridge
    
    /// Creates a new instance of `StopTrackingProxyImpl`
    ///
    /// - Parameter contensquareSDK: The `ContentsquareSDKBridge` used to access contentsquare API.
    internal init(contensquareSDK: ContentsquareSDKBridge) {
        self._contensquareSDK = contensquareSDK
    }
    
    func stopTracking() throws {
        try _contensquareSDK.stopTracking()
    }
}
